@@ -28,6 +28,25 @@
 
 G_BEGIN_DECLS
 
+/**
+ * LIBXFCE4WINDOWING_HAS_X11:
+ *
+ * A macro that is defined if libxfce4windowing was compiled with X11 support.
+ *
+ * Since: 4.19.3
+ */
+#define LIBXFCE4WINDOWING_HAS_X11
+
+/**
+ * LIBXFCE4WINDOWING_HAS_WAYLAND:
+ *
+ * A macro that is defined if libxfce4windowing was compiled with Wayland
+ * support.
+ *
+ * Since: 4.19.3
+ */
+#define LIBXFCE4WINDOWING_HAS_WAYLAND
+
 /**
  * LIBXFCE4WINDOWING_MAJOR_VERSION:
  *
@@ -53,7 +72,7 @@ G_BEGIN_DECLS
  * that can be used by the C pre-processor.
  *
  */
-#define LIBXFCE4WINDOWING_MICRO_VERSION (2)
+#define LIBXFCE4WINDOWING_MICRO_VERSION (4)
 
 /**
  * LIBXFCE4WINDOWING_CHECK_VERSION:
