@@ -33,7 +33,9 @@
  * implements this interface will be returned.
  **/
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include "libxfce4windowing-private.h"
 #include "xfw-application-private.h"
@@ -167,8 +169,7 @@ static void
 xfw_application_set_property(GObject *object,
                              guint prop_id,
                              const GValue *value,
-                             GParamSpec *pspec)
-{
+                             GParamSpec *pspec) {
     G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 }
 
@@ -176,8 +177,7 @@ static void
 xfw_application_get_property(GObject *object,
                              guint prop_id,
                              GValue *value,
-                             GParamSpec *pspec)
-{
+                             GParamSpec *pspec) {
     XfwApplication *app = XFW_APPLICATION(object);
 
     switch (prop_id) {
