@@ -38,14 +38,18 @@
  * this interface will be returned.
  **/
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <limits.h>
 
 #include "libxfce4windowing-private.h"
+#include "xfw-monitor-private.h"
 #include "xfw-screen-private.h"
 #include "xfw-util.h"
 #include "xfw-window.h"
+#include "xfw-workspace-manager.h"
 
 #ifdef ENABLE_X11
 #include "xfw-screen-x11.h"
@@ -55,12 +59,47 @@
 #include "xfw-screen-wayland.h"
 #endif
 
+#define XFW_SCREEN_GET_PRIVATE(screen) ((XfwScreenPrivate *)xfw_screen_get_instance_private((XfwScreen *)screen))
 #define GDK_SCREEN_XFW_SCREEN_KEY "libxfce4windowing-xfw-screen"
 
-G_DEFINE_INTERFACE(XfwScreen, xfw_screen, G_TYPE_OBJECT)
+typedef struct _XfwXcreenPrivate {
+    GdkScreen *gdk_screen;
+    XfwWorkspaceManager *workspace_manager;
+    GList *monitors;
+    XfwMonitor *primary_monitor;
+    XfwWindow *active_window;
+    guint32 show_desktop : 1;
+} XfwScreenPrivate;
+
+enum {
+    PROP0,
+    PROP_SCREEN,
+    PROP_WORKSPACE_MANAGER,
+    PROP_ACTIVE_WINDOW,
+    PROP_SHOW_DESKTOP,
+};
+
+static void xfw_screen_set_property(GObject *object,
+                                    guint property_id,
+                                    const GValue *value,
+                                    GParamSpec *pspec);
+static void xfw_screen_get_property(GObject *object,
+                                    guint property_id,
+                                    GValue *value,
+                                    GParamSpec *pspec);
+static void xfw_screen_finalize(GObject *object);
+
+
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE(XfwScreen, xfw_screen, G_TYPE_OBJECT)
+
 
 static void
-xfw_screen_default_init(XfwScreenIface *iface) {
+xfw_screen_class_init(XfwScreenClass *klass) {
+    GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
+    gobject_class->set_property = xfw_screen_set_property;
+    gobject_class->get_property = xfw_screen_get_property;
+    gobject_class->finalize = xfw_screen_finalize;
+
     /**
      * XfwScreen::window-opened:
      * @screen: the object which received the signal.
@@ -71,7 +110,7 @@ xfw_screen_default_init(XfwScreenIface *iface) {
     g_signal_new("window-opened",
                  XFW_TYPE_SCREEN,
                  G_SIGNAL_RUN_LAST,
-                 G_STRUCT_OFFSET(XfwScreenIface, window_opened),
+                 G_STRUCT_OFFSET(XfwScreenClass, window_opened),
                  NULL, NULL,
                  g_cclosure_marshal_VOID__OBJECT,
                  G_TYPE_NONE, 1,
@@ -91,7 +130,7 @@ xfw_screen_default_init(XfwScreenIface *iface) {
     g_signal_new("active-window-changed",
                  XFW_TYPE_SCREEN,
                  G_SIGNAL_RUN_LAST,
-                 G_STRUCT_OFFSET(XfwScreenIface, active_window_changed),
+                 G_STRUCT_OFFSET(XfwScreenClass, active_window_changed),
                  NULL, NULL,
                  g_cclosure_marshal_VOID__OBJECT,
                  G_TYPE_NONE, 1,
@@ -110,7 +149,7 @@ xfw_screen_default_init(XfwScreenIface *iface) {
     g_signal_new("window-stacking-changed",
                  XFW_TYPE_SCREEN,
                  G_SIGNAL_RUN_LAST,
-                 G_STRUCT_OFFSET(XfwScreenIface, window_stacking_changed),
+                 G_STRUCT_OFFSET(XfwScreenClass, window_stacking_changed),
                  NULL, NULL,
                  g_cclosure_marshal_VOID__VOID,
                  G_TYPE_NONE, 0);
@@ -125,7 +164,7 @@ xfw_screen_default_init(XfwScreenIface *iface) {
     g_signal_new("window-closed",
                  XFW_TYPE_SCREEN,
                  G_SIGNAL_RUN_LAST,
-                 G_STRUCT_OFFSET(XfwScreenIface, window_closed),
+                 G_STRUCT_OFFSET(XfwScreenClass, window_closed),
                  NULL, NULL,
                  g_cclosure_marshal_VOID__OBJECT,
                  G_TYPE_NONE, 1,
@@ -142,22 +181,86 @@ xfw_screen_default_init(XfwScreenIface *iface) {
     g_signal_new("window-manager-changed",
                  XFW_TYPE_SCREEN,
                  G_SIGNAL_RUN_LAST,
-                 G_STRUCT_OFFSET(XfwScreenIface, window_manager_changed),
+                 G_STRUCT_OFFSET(XfwScreenClass, window_manager_changed),
                  NULL, NULL,
                  g_cclosure_marshal_VOID__VOID,
                  G_TYPE_NONE, 0);
 
     /**
-     * XfwScreen:screen:
+     * XfwScreen::monitor-added:
+     * @screen: the object which received the signal.
+     * @monitor: the monitor that was added.
+     *
+     * Emitted when a monitor is added to @screen.
+     *
+     * Since: 4.19.4
+     **/
+    g_signal_new("monitor-added",
+                 XFW_TYPE_SCREEN,
+                 G_SIGNAL_RUN_LAST,
+                 0,
+                 NULL, NULL,
+                 g_cclosure_marshal_VOID__OBJECT,
+                 G_TYPE_NONE, 1,
+                 XFW_TYPE_MONITOR);
+
+    /**
+     * XfwScreen::monitor-removed:
+     * @screen: the object which received the signal.
+     * @monitor: the monitor that was removed.
+     *
+     * Emitted when a monitor is removed from @screen.
+     *
+     * Since: 4.19.4
+     **/
+    g_signal_new("monitor-removed",
+                 XFW_TYPE_SCREEN,
+                 G_SIGNAL_RUN_LAST,
+                 0,
+                 NULL, NULL,
+                 g_cclosure_marshal_VOID__OBJECT,
+                 G_TYPE_NONE, 1,
+                 XFW_TYPE_MONITOR);
+    /**
+     * XfwScreen::monitors-changed:
+     * @screen: the object which received the signal.
+     *
+     * Emitted when one of the following has changed about the monitors
+     * attached to @screen:
+     *
+     *   * A monitor was added.
+     *   * A monitor was removed.
+     *   * A monitor's resolution changed (including if the scale factor changed).
+     *   * A monitor was re-positioned in the global screen space.
+     *   * Which monitor is primary has changed.
+     *
+     * Note that changes such as the subpixel layout or model name will not
+     * result in the emission of this signal.  Connect to the propert notify
+     * signals on #XfwMonitor to be notified of changes in other aspects of the
+     * monitor.
+     *
+     * Since: 4.19.4
+     **/
+    g_signal_new("monitors-changed",
+                 XFW_TYPE_SCREEN,
+                 G_SIGNAL_RUN_LAST,
+                 0,
+                 NULL, NULL,
+                 g_cclosure_marshal_VOID__VOID,
+                 G_TYPE_NONE, 0);
+
+    /**
+     * XfwScreen:gdk-screen:
      *
      * The #GdkScreen instance used to construct this #XfwScreen.
      **/
-    g_object_interface_install_property(iface,
-                                        g_param_spec_object("screen",
-                                                            "screen",
-                                                            "screen",
-                                                            GDK_TYPE_SCREEN,
-                                                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property(gobject_class,
+                                    PROP_SCREEN,
+                                    g_param_spec_object("gdk-screen",
+                                                        "gdk-screen",
+                                                        "GdkScreen",
+                                                        GDK_TYPE_SCREEN,
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
     /**
      * XfwScreen:workspace-manager:
@@ -165,36 +268,103 @@ xfw_screen_default_init(XfwScreenIface *iface) {
      * The #XfwWorkspaceManager that manages and describes workspace groups
      * and workspaces on this screen instance.
      **/
-    g_object_interface_install_property(iface,
-                                        g_param_spec_object("workspace-manager",
-                                                            "workspace-manager",
-                                                            "workspace-manager",
-                                                            XFW_TYPE_WORKSPACE_MANAGER,
-                                                            G_PARAM_READABLE));
+    g_object_class_install_property(gobject_class,
+                                    PROP_WORKSPACE_MANAGER,
+                                    g_param_spec_object("workspace-manager",
+                                                        "workspace-manager",
+                                                        "workspace-manager",
+                                                        XFW_TYPE_WORKSPACE_MANAGER,
+                                                        G_PARAM_READABLE));
 
     /**
      * XfwScreen:active-window:
      *
      * The currently-active window.
      **/
-    g_object_interface_install_property(iface,
-                                        g_param_spec_object("active-window",
-                                                            "active-window",
-                                                            "active-window",
-                                                            XFW_TYPE_WINDOW,
-                                                            G_PARAM_READABLE));
+    g_object_class_install_property(gobject_class,
+                                    PROP_ACTIVE_WINDOW,
+                                    g_param_spec_object("active-window",
+                                                        "active-window",
+                                                        "active-window",
+                                                        XFW_TYPE_WINDOW,
+                                                        G_PARAM_READABLE));
 
     /**
      * XfwScreen:show-desktop:
      *
      * Whether or not to show the desktop.
      **/
-    g_object_interface_install_property(iface,
-                                        g_param_spec_boolean("show-desktop",
-                                                             "show-desktop",
-                                                             "show-desktop",
-                                                             FALSE,
-                                                             G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY));
+    g_object_class_install_property(gobject_class,
+                                    PROP_SHOW_DESKTOP,
+                                    g_param_spec_boolean("show-desktop",
+                                                         "show-desktop",
+                                                         "show-desktop",
+                                                         FALSE,
+                                                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY));
+}
+
+static void
+xfw_screen_init(XfwScreen *screen) {}
+
+static void
+xfw_screen_set_property(GObject *object, guint property_id, const GValue *value, GParamSpec *pspec) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(object);
+
+    switch (property_id) {
+        case PROP_SCREEN:
+            priv->gdk_screen = g_value_get_object(value);
+            break;
+
+        case PROP_WORKSPACE_MANAGER:
+            priv->workspace_manager = g_value_get_object(value);
+            break;
+
+        case PROP_SHOW_DESKTOP:
+            xfw_screen_set_show_desktop(XFW_SCREEN(object), g_value_get_boolean(value));
+            break;
+
+        default:
+            G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
+            break;
+    }
+}
+
+static void
+xfw_screen_get_property(GObject *object, guint property_id, GValue *value, GParamSpec *pspec) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(object);
+
+    switch (property_id) {
+        case PROP_SCREEN:
+            g_value_set_object(value, priv->gdk_screen);
+            break;
+
+        case PROP_WORKSPACE_MANAGER:
+            g_value_set_object(value, priv->workspace_manager);
+            break;
+
+        case PROP_ACTIVE_WINDOW:
+            g_value_set_object(value, priv->active_window);
+            break;
+
+        case PROP_SHOW_DESKTOP:
+            g_value_set_boolean(value, priv->show_desktop);
+            break;
+
+        default:
+            G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
+            break;
+    }
+}
+
+static void
+xfw_screen_finalize(GObject *object) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(object);
+
+    g_list_free_full(priv->monitors, g_object_unref);
+
+    g_object_unref(priv->workspace_manager);
+
+    G_OBJECT_CLASS(xfw_screen_parent_class)->finalize(object);
 }
 
 /**
@@ -209,10 +379,8 @@ xfw_screen_default_init(XfwScreenIface *iface) {
  **/
 XfwWorkspaceManager *
 xfw_screen_get_workspace_manager(XfwScreen *screen) {
-    XfwScreenIface *iface;
     g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
-    iface = XFW_SCREEN_GET_IFACE(screen);
-    return (*iface->get_workspace_manager)(screen);
+    return XFW_SCREEN_GET_PRIVATE(screen)->workspace_manager;
 }
 
 /**
@@ -229,10 +397,9 @@ xfw_screen_get_workspace_manager(XfwScreen *screen) {
  **/
 GList *
 xfw_screen_get_windows(XfwScreen *screen) {
-    XfwScreenIface *iface;
     g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
-    iface = XFW_SCREEN_GET_IFACE(screen);
-    return (*iface->get_windows)(screen);
+    XfwScreenClass *klass = XFW_SCREEN_GET_CLASS(screen);
+    return klass->get_windows(screen);
 }
 
 /**
@@ -248,10 +415,9 @@ xfw_screen_get_windows(XfwScreen *screen) {
  **/
 GList *
 xfw_screen_get_windows_stacked(XfwScreen *screen) {
-    XfwScreenIface *iface;
     g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
-    iface = XFW_SCREEN_GET_IFACE(screen);
-    return (*iface->get_windows_stacked)(screen);
+    XfwScreenClass *klass = XFW_SCREEN_GET_CLASS(screen);
+    return klass->get_windows_stacked(screen);
 }
 
 /**
@@ -265,10 +431,50 @@ xfw_screen_get_windows_stacked(XfwScreen *screen) {
  **/
 XfwWindow *
 xfw_screen_get_active_window(XfwScreen *screen) {
-    XfwScreenIface *iface;
     g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
-    iface = XFW_SCREEN_GET_IFACE(screen);
-    return (*iface->get_active_window)(screen);
+    return XFW_SCREEN_GET_PRIVATE(screen)->active_window;
+}
+
+/**
+ * xfw_screen_get_monitors:
+ * @screen: an #XfwScreen.
+ *
+ * Retrieves the list of monitors currently attached and enabled on @screen.
+ *
+ * Return value: (nullable) (element-type XfwMonitor) (transfer none): the list
+ * of #XfwMonitor on @screen, or %NULL if there are no connected/enabled
+ * monitors.  The list and its contents are owned by @screen.
+ *
+ * Since: 4.19.4
+ **/
+GList *
+xfw_screen_get_monitors(XfwScreen *screen) {
+    g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
+    return XFW_SCREEN_GET_PRIVATE(screen)->monitors;
+}
+
+/**
+ * xfw_screen_get_primary_monitor:
+ * @screen: an #XfwScreen.
+ *
+ * Returns the monitor designated as "primary".
+ *
+ * This function will do its best to return something other than %NULL.  If the
+ * windowing system has no concept of a primary monitor, or if the primary
+ * monitor is unset, a likely candidate will be chosen from the list of
+ * available monitors.
+ *
+ * However, if no monitors are connected, %NULL can still be returned.
+ *
+ * Return value: (nullable) (transfer none): @screen's primary #XfwMonitor, or
+ * %NULL.
+ *
+ * Since: 4.19.4
+ **/
+XfwMonitor *
+xfw_screen_get_primary_monitor(XfwScreen *screen) {
+    g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
+    return XFW_SCREEN_GET_PRIVATE(screen)->primary_monitor;
 }
 
 /**
@@ -279,10 +485,8 @@ xfw_screen_get_active_window(XfwScreen *screen) {
  **/
 gboolean
 xfw_screen_get_show_desktop(XfwScreen *screen) {
-    XfwScreenIface *iface;
     g_return_val_if_fail(XFW_IS_SCREEN(screen), FALSE);
-    iface = XFW_SCREEN_GET_IFACE(screen);
-    return (*iface->get_show_desktop)(screen);
+    return XFW_SCREEN_GET_PRIVATE(screen)->show_desktop;
 }
 
 /**
@@ -302,10 +506,11 @@ xfw_screen_get_show_desktop(XfwScreen *screen) {
  **/
 void
 xfw_screen_set_show_desktop(XfwScreen *screen, gboolean show) {
-    XfwScreenIface *iface;
     g_return_if_fail(XFW_IS_SCREEN(screen));
-    iface = XFW_SCREEN_GET_IFACE(screen);
-    (*iface->set_show_desktop)(screen, show);
+    if (XFW_SCREEN_GET_PRIVATE(screen)->show_desktop != !!show) {
+        XfwScreenClass *klass = XFW_SCREEN_GET_CLASS(screen);
+        klass->set_show_desktop(screen, show);
+    }
 }
 
 static void
@@ -323,14 +528,15 @@ xfw_screen_get(GdkScreen *gdk_screen) {
 #ifdef ENABLE_X11
         if (xfw_windowing_get() == XFW_WINDOWING_X11) {
             screen = g_object_new(XFW_TYPE_SCREEN_X11,
-                                  "screen", gdk_screen,
+                                  "gdk-screen", gdk_screen,
                                   NULL);
         } else
-#endif  /* ENABLE_X11 */
+#endif /* ENABLE_X11 */
 #ifdef ENABLE_WAYLAND
-        if (xfw_windowing_get() == XFW_WINDOWING_WAYLAND) {
+            if (xfw_windowing_get() == XFW_WINDOWING_WAYLAND)
+        {
             screen = g_object_new(XFW_TYPE_SCREEN_WAYLAND,
-                                  "screen", gdk_screen,
+                                  "gdk-screen", gdk_screen,
                                   NULL);
         } else
 #endif
@@ -362,10 +568,76 @@ xfw_screen_get_default(void) {
     return xfw_screen_get(gdk_screen_get_default());
 }
 
+GdkScreen *
+_xfw_screen_get_gdk_screen(XfwScreen *screen) {
+    g_return_val_if_fail(XFW_IS_SCREEN(screen), NULL);
+    return XFW_SCREEN_GET_PRIVATE(screen)->gdk_screen;
+}
+
 void
-_xfw_screen_install_properties(GObjectClass *gklass) {
-    g_object_class_override_property(gklass, SCREEN_PROP_SCREEN, "screen");
-    g_object_class_override_property(gklass, SCREEN_PROP_WORKSPACE_MANAGER, "workspace-manager");
-    g_object_class_override_property(gklass, SCREEN_PROP_ACTIVE_WINDOW, "active-window");
-    g_object_class_override_property(gklass, SCREEN_PROP_SHOW_DESKTOP, "show-desktop");
+_xfw_screen_set_workspace_manager(XfwScreen *screen, XfwWorkspaceManager *workspace_manager) {
+    XFW_SCREEN_GET_PRIVATE(screen)->workspace_manager = workspace_manager;
+}
+
+GList *
+_xfw_screen_steal_monitors(XfwScreen *screen) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(screen);
+    GList *monitors = priv->monitors;
+    priv->monitors = NULL;
+    return monitors;
+}
+
+void
+_xfw_screen_set_monitors(XfwScreen *screen, GList *monitors, GList *added, GList *removed) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(screen);
+    g_list_free_full(priv->monitors, g_object_unref);
+    priv->monitors = monitors;
+
+    for (GList *l = monitors; l != NULL; l = l->next) {
+        XfwMonitor *monitor = XFW_MONITOR(l->data);
+        if (xfw_monitor_is_primary(monitor)) {
+            priv->primary_monitor = monitor;
+            break;
+        }
+    }
+
+    MonitorPendingChanges changed = 0;
+    for (GList *l = monitors; l != NULL; l = l->next) {
+        changed |= _xfw_monitor_notify_pending_changes(XFW_MONITOR(l->data));
+    }
+
+    for (GList *l = added; l != NULL; l = l->next) {
+        g_signal_emit_by_name(screen, "monitor-added", XFW_MONITOR(l->data));
+    }
+
+    for (GList *l = removed; l != NULL; l = l->next) {
+        g_signal_emit_by_name(screen, "monitor-removed", XFW_MONITOR(l->data));
+    }
+
+    if ((changed & MONITORS_CHANGED_MASK) != 0 || added != NULL || removed != NULL) {
+        // Only notify if what has changed is relevant to positioning or size, or if
+        // a monitor was added or removed, or the primary monitor has changed.
+        g_signal_emit_by_name(screen, "monitors-changed");
+    }
+}
+
+void
+_xfw_screen_set_active_window(XfwScreen *screen, XfwWindow *window) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(screen);
+    if (priv->active_window != window) {
+        XfwWindow *previous_window = priv->active_window;
+        priv->active_window = window;
+
+        g_object_notify(G_OBJECT(screen), "active-window");
+        g_signal_emit_by_name(screen, "active-window-changed", previous_window);
+    }
+}
+
+void
+_xfw_screen_set_show_desktop(XfwScreen *screen, gboolean show_desktop) {
+    XfwScreenPrivate *priv = XFW_SCREEN_GET_PRIVATE(screen);
+    if (priv->show_desktop != show_desktop) {
+        priv->show_desktop = show_desktop;
+        g_object_notify(G_OBJECT(screen), "show-desktop");
+    }
 }
