@@ -17,19 +17,22 @@
  * MA 02110-1301 USA
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <gdk/gdkwayland.h>
 
 #include "protocols/wlr-foreign-toplevel-management-unstable-v1-client.h"
 
 #include "libxfce4windowing-private.h"
+#include "xfw-application-wayland.h"
+#include "xfw-monitor-wayland.h"
 #include "xfw-screen-wayland.h"
+#include "xfw-screen.h"
 #include "xfw-util.h"
 #include "xfw-window-private.h"
 #include "xfw-window-wayland.h"
-#include "xfw-application-wayland.h"
-#include "xfw-screen.h"
 
 enum {
     PROP0,
@@ -566,52 +569,56 @@ toplevel_state(void *data, struct zwlr_foreign_toplevel_handle_v1 *wl_toplevel,
         XfwScreen *screen = _xfw_window_get_screen(XFW_WINDOW(window));
 
         if (new_state & XFW_WINDOW_STATE_ACTIVE) {
-            _xfw_screen_wayland_set_active_window(XFW_SCREEN_WAYLAND(screen), XFW_WINDOW(window));
+            _xfw_screen_set_active_window(screen, XFW_WINDOW(window));
         } else if (xfw_screen_get_active_window(screen) == XFW_WINDOW(window)) {
-            _xfw_screen_wayland_set_active_window(XFW_SCREEN_WAYLAND(screen), NULL);
+            _xfw_screen_set_active_window(screen, NULL);
         }
     }
 }
 
 static void
 toplevel_parent(void *data, struct zwlr_foreign_toplevel_handle_v1 *wl_toplevel, struct zwlr_foreign_toplevel_handle_v1 *wl_parent) {
-
 }
 
 static void
 toplevel_output_enter(void *data, struct zwlr_foreign_toplevel_handle_v1 *wl_toplevel, struct wl_output *output) {
-    XfwWindowWayland *window = XFW_WINDOW_WAYLAND(data);
-    GdkDisplay *display = gdk_display_get_default();
-    GdkMonitor *monitor;
-    gint n_monitors = gdk_display_get_n_monitors(display);
+    g_debug("toplevel %u output_enter", wl_proxy_get_id((struct wl_proxy *)wl_toplevel));
 
-    for (gint n = 0; n < n_monitors; n++) {
-        monitor = gdk_display_get_monitor(display, n);
-        if (output == gdk_wayland_monitor_get_wl_output(monitor)) {
+    XfwWindowWayland *window = XFW_WINDOW_WAYLAND(data);
+    XfwScreen *screen = _xfw_window_get_screen(XFW_WINDOW(window));
+    GList *monitors = xfw_screen_get_monitors(screen);
+
+    for (GList *l = monitors; l != NULL; l = l->next) {
+        XfwMonitorWayland *monitor = XFW_MONITOR_WAYLAND(l->data);
+        if (output == _xfw_monitor_wayland_get_wl_output(monitor)
+            && g_list_find(window->priv->monitors, monitor) == NULL)
+        {
             window->priv->monitors = g_list_prepend(window->priv->monitors, monitor);
+            g_object_notify(G_OBJECT(window), "monitors");
             break;
         }
     }
-
-    g_object_notify(G_OBJECT(window), "monitors");
 }
 
 static void
 toplevel_output_leave(void *data, struct zwlr_foreign_toplevel_handle_v1 *wl_toplevel, struct wl_output *output) {
-    XfwWindowWayland *window = XFW_WINDOW_WAYLAND(data);
-    GdkDisplay *display = gdk_display_get_default();
-    GdkMonitor *monitor;
-    gint n_monitors = gdk_display_get_n_monitors(display);
+    g_debug("toplevel %u output_leave", wl_proxy_get_id((struct wl_proxy *)wl_toplevel));
 
-    for (gint n = 0; n < n_monitors; n++) {
-        monitor = gdk_display_get_monitor(display, n);
-        if (output == gdk_wayland_monitor_get_wl_output(monitor)) {
-            window->priv->monitors = g_list_remove(window->priv->monitors, monitor);
+    XfwWindowWayland *window = XFW_WINDOW_WAYLAND(data);
+    XfwScreen *screen = _xfw_window_get_screen(XFW_WINDOW(window));
+    GList *monitors = xfw_screen_get_monitors(screen);
+
+    for (GList *l = monitors; l != NULL; l = l->next) {
+        XfwMonitorWayland *monitor = XFW_MONITOR_WAYLAND(l->data);
+        if (output == _xfw_monitor_wayland_get_wl_output(monitor)) {
+            GList *lm = g_list_find(window->priv->monitors, monitor);
+            if (lm != NULL) {
+                window->priv->monitors = g_list_delete_link(window->priv->monitors, lm);
+                g_object_notify(G_OBJECT(window), "monitors");
+            }
             break;
         }
     }
-
-    g_object_notify(G_OBJECT(window), "monitors");
 }
 
 static void
@@ -635,7 +642,7 @@ toplevel_done(void *data, struct zwlr_foreign_toplevel_handle_v1 *wl_toplevel) {
 
         g_signal_emit_by_name(screen, "window-opened", window);
         if (window->priv->state & XFW_WINDOW_STATE_ACTIVE) {
-            _xfw_screen_wayland_set_active_window(XFW_SCREEN_WAYLAND(screen), XFW_WINDOW(window));
+            _xfw_screen_set_active_window(screen, XFW_WINDOW(window));
         }
     }
 }
