@@ -37,7 +37,9 @@
  * implements this interface will be returned.
  **/
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <limits.h>
 
@@ -49,14 +51,16 @@
 
 G_DEFINE_INTERFACE(XfwWorkspace, xfw_workspace, G_TYPE_OBJECT)
 
-G_DEFINE_FLAGS_TYPE(XfwWorkspaceState, xfw_workspace_state,
+G_DEFINE_FLAGS_TYPE(
+    XfwWorkspaceState, xfw_workspace_state,
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_STATE_NONE, "none"),
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_STATE_ACTIVE, "active"),
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_STATE_URGENT, "urgent"),
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_STATE_HIDDEN, "hidden"),
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_STATE_VIRTUAL, "virtual"))
 
-G_DEFINE_FLAGS_TYPE(XfwWorkspaceCapabilities, xfw_workspace_capabilities,
+G_DEFINE_FLAGS_TYPE(
+    XfwWorkspaceCapabilities, xfw_workspace_capabilities,
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_CAPABILITIES_NONE, "none"),
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_CAPABILITIES_ACTIVATE, "activate"),
     G_DEFINE_ENUM_VALUE(XFW_WORKSPACE_CAPABILITIES_REMOVE, "remove"))
@@ -202,6 +206,30 @@ xfw_workspace_default_init(XfwWorkspaceIface *iface) {
                                                           "number",
                                                           0, UINT_MAX, 0,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+
+    /**
+     * XfwWorkspace:layout-row:
+     *
+     * The x-coordinate of the workspace on a 2D grid.
+     */
+    g_object_interface_install_property(iface,
+                                        g_param_spec_int("layout-row",
+                                                         "layout-row",
+                                                         "layout-row",
+                                                         -1, G_MAXINT, -1,
+                                                         G_PARAM_READABLE));
+
+    /**
+     * XfwWorkspace:layout-column:
+     *
+     * The y-coordinate of the workspace on a 2D grid.
+     */
+    g_object_interface_install_property(iface,
+                                        g_param_spec_int("layout-column",
+                                                         "layout-column",
+                                                         "layout-column",
+                                                         -1, G_MAXINT, -1,
+                                                         G_PARAM_READABLE));
 }
 
 /**
@@ -466,4 +494,6 @@ _xfw_workspace_install_properties(GObjectClass *gklass) {
     g_object_class_override_property(gklass, WORKSPACE_PROP_CAPABILITIES, "capabilities");
     g_object_class_override_property(gklass, WORKSPACE_PROP_STATE, "state");
     g_object_class_override_property(gklass, WORKSPACE_PROP_NUMBER, "number");
+    g_object_class_override_property(gklass, WORKSPACE_PROP_LAYOUT_ROW, "layout-row");
+    g_object_class_override_property(gklass, WORKSPACE_PROP_LAYOUT_COLUMN, "layout-column");
 }
